# frozen_string_literal: true

module Hermes
  module Api
    module Dmo
      class EntityCodesController < Hermes::Api::Dmo::ApplicationController
        before_action :authorize_entreprise!, except: [:show, :index]

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $eq
          $all
        ]

        ACCEPTABLE_PARAMS = %w[
          code
          expire_at
          entity_id
          applicant_id
          created_at
          updated_at
        ]

        MUTATE_PARAMS = %i[
          code
          expire_at
          entity_id
          applicant_id
        ]
        mutate_params_only *MUTATE_PARAMS

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          valid_operators *VALID_OPERATORS
          super
        end

        def destroy
          return render_json_error(:not_found, :instance_not_found) unless @instance
          return render_json_error(:unauthorized, :not_owned) unless @instance.user_id == @user.id
          return render(json: @instance.errors, status: :unprocessable_entity) unless @instance.destroy

          render(body: nil, status: :no_content)
        end

        private

        def authorize_entreprise!
          return render_json_error(:unauthorized, :not_entreprise) unless current_user_roles.include?('entreprise') || current_user_roles.include?('superadministrateur')
        end
      end
    end
  end
end